# mypy-boto3-servicecatalog

[![PyPI - mypy-boto3-servicecatalog](https://img.shields.io/pypi/v/mypy-boto3-servicecatalog.svg?color=blue)](https://pypi.org/project/mypy-boto3-servicecatalog)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-servicecatalog.svg?color=blue)](https://pypi.org/project/mypy-boto3-servicecatalog)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.ServiceCatalog 1.12.24](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/servicecatalog.html#ServiceCatalog) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 1.0.5](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-servicecatalog](#mypy-boto3-servicecatalog)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `ServiceCatalog` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-servicecatalog]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3 import servicecatalog
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_servicecatalog as servicecatalog

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("servicecatalog")
client: servicecatalog.ServiceCatalogClient = boto3.client("servicecatalog")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: servicecatalog.ServiceCatalogClient = session.client("servicecatalog")


# Paginators need type annotation on creation
list_accepted_portfolio_shares_paginator: servicecatalog.ListAcceptedPortfolioSharesPaginator = client.get_paginator("list_accepted_portfolio_shares")
list_constraints_for_portfolio_paginator: servicecatalog.ListConstraintsForPortfolioPaginator = client.get_paginator("list_constraints_for_portfolio")
list_launch_paths_paginator: servicecatalog.ListLaunchPathsPaginator = client.get_paginator("list_launch_paths")
list_organization_portfolio_access_paginator: servicecatalog.ListOrganizationPortfolioAccessPaginator = client.get_paginator("list_organization_portfolio_access")
list_portfolios_paginator: servicecatalog.ListPortfoliosPaginator = client.get_paginator("list_portfolios")
list_portfolios_for_product_paginator: servicecatalog.ListPortfoliosForProductPaginator = client.get_paginator("list_portfolios_for_product")
list_principals_for_portfolio_paginator: servicecatalog.ListPrincipalsForPortfolioPaginator = client.get_paginator("list_principals_for_portfolio")
list_provisioned_product_plans_paginator: servicecatalog.ListProvisionedProductPlansPaginator = client.get_paginator("list_provisioned_product_plans")
list_provisioning_artifacts_for_service_action_paginator: servicecatalog.ListProvisioningArtifactsForServiceActionPaginator = client.get_paginator("list_provisioning_artifacts_for_service_action")
list_record_history_paginator: servicecatalog.ListRecordHistoryPaginator = client.get_paginator("list_record_history")
list_resources_for_tag_option_paginator: servicecatalog.ListResourcesForTagOptionPaginator = client.get_paginator("list_resources_for_tag_option")
list_service_actions_paginator: servicecatalog.ListServiceActionsPaginator = client.get_paginator("list_service_actions")
list_service_actions_for_provisioning_artifact_paginator: servicecatalog.ListServiceActionsForProvisioningArtifactPaginator = client.get_paginator("list_service_actions_for_provisioning_artifact")
list_tag_options_paginator: servicecatalog.ListTagOptionsPaginator = client.get_paginator("list_tag_options")
scan_provisioned_products_paginator: servicecatalog.ScanProvisionedProductsPaginator = client.get_paginator("scan_provisioned_products")
search_products_as_admin_paginator: servicecatalog.SearchProductsAsAdminPaginator = client.get_paginator("search_products_as_admin")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3_builder) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from the documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) for readability.